======
random
======

shuffle_together
----------------

.. autofunction:: satella.random.shuffle_together

random_binary
-------------

.. autofunction:: satella.random.random_binary

random_word
-----------

.. autofunction:: satella.random.random_word
